@@ -1,6 +1,6 @@
-/* $Id: terminal-preferences.c 23253 2006-10-01 13:05:04Z benny $ */
+/* $Id: terminal-preferences.c 26301 2007-11-15 20:35:13Z benny $ */
 /*-
- * Copyright (c) 2004-2006 os-cillation e.K.
+ * Copyright (c) 2004-2007 os-cillation e.K.
  *
  * Written by Benedikt Meurer <benny@xfce.org>.
  *
@@ -37,6 +37,7 @@
 #include <terminal/terminal-enum-types.h>
 #include <terminal/terminal-monitor.h>
 #include <terminal/terminal-preferences.h>
+#include <terminal/terminal-private.h>
 
 
 
@@ -51,7 +52,6 @@ enum
   PROP_ACCEL_COPY,
   PROP_ACCEL_PASTE,
   PROP_ACCEL_PASTE_SELECTION,
-  PROP_ACCEL_EDIT_HELPERS,
   PROP_ACCEL_PREFERENCES,
   PROP_ACCEL_SHOW_MENUBAR,
   PROP_ACCEL_SHOW_TOOLBARS,
@@ -104,8 +104,6 @@ enum
   PROP_FONT_ALLOW_BOLD,
   PROP_FONT_ANTI_ALIAS,
   PROP_FONT_NAME,
-  PROP_HELPER_MAILREADER,
-  PROP_HELPER_WEBBROWSER,
   PROP_MISC_ALWAYS_SHOW_TABS,
   PROP_MISC_BELL,
   PROP_MISC_BORDERS_DEFAULT,
@@ -119,10 +117,12 @@ enum
   PROP_MISC_CYCLE_TABS,
   PROP_MISC_TAB_CLOSE_BUTTONS,
   PROP_MISC_TAB_POSITION,
+  PROP_MISC_HIGHLIGHT_URLS,
   PROP_SCROLLING_BAR,
   PROP_SCROLLING_LINES,
   PROP_SCROLLING_ON_OUTPUT,
   PROP_SCROLLING_ON_KEYSTROKE,
+  PROP_SCROLLING_SINGLE_LINE,
   PROP_SHORTCUTS_NO_MENUKEY,
   PROP_SHORTCUTS_NO_MNEMONICS,
   PROP_TITLE_INITIAL,
@@ -383,17 +383,6 @@ terminal_preferences_class_init (TerminalPreferencesClass *klass)
                                                         NULL,
                                                         EXO_PARAM_READWRITE));
 
-  /**
-   * TerminalPreferences:accel-edit-helpers:
-   **/
-  g_object_class_install_property (gobject_class,
-                                   PROP_ACCEL_EDIT_HELPERS,
-                                   g_param_spec_string ("accel-edit-helpers",
-                                                        _("Applications"),
-                                                        _("Applications"),
-                                                        _("Disabled"),
-                                                        EXO_PARAM_READWRITE));
-
   /**
    * TerminalPreferences:accel-preferences:
    **/
@@ -975,28 +964,6 @@ terminal_preferences_class_init (TerminalPreferencesClass *klass)
                                                         "Monospace 12",
                                                         EXO_PARAM_READWRITE));
 
-  /**
-   * TerminalPreferences:helper-mailreader:
-   **/
-  g_object_class_install_property (gobject_class,
-                                   PROP_HELPER_MAILREADER,
-                                   g_param_spec_string ("helper-mailreader",
-                                                        "helper-mailreader",
-                                                        "helper-mailreader",
-                                                        NULL,
-                                                        EXO_PARAM_READWRITE));
-
-  /**
-   * TerminalPreferences:helper-webbrowser:
-   **/
-  g_object_class_install_property (gobject_class,
-                                   PROP_HELPER_WEBBROWSER,
-                                   g_param_spec_string ("helper-webbrowser",
-                                                        "helper-webbrowser",
-                                                        "helper-webbrowser",
-                                                        NULL,
-                                                        EXO_PARAM_READWRITE));
-
   /**
    * TerminalPreferences:misc-always-show-tabs:
    **/
@@ -1140,6 +1107,17 @@ terminal_preferences_class_init (TerminalPreferencesClass *klass)
                                                       GTK_POS_TOP,
                                                       EXO_PARAM_READWRITE));
 
+  /**
+   * TerminalPreferences:misc-highlight-urls:
+   **/
+  g_object_class_install_property (gobject_class,
+                                   PROP_MISC_HIGHLIGHT_URLS,
+                                   g_param_spec_boolean ("misc-highlight-urls",
+                                                         "misc-highlight-urls",
+                                                         "misc-highlight-urls",
+                                                         TRUE,
+                                                         EXO_PARAM_READWRITE));
+
   /**
    * TerminalPreferences:scrolling-bar:
    **/
@@ -1185,6 +1163,19 @@ terminal_preferences_class_init (TerminalPreferencesClass *klass)
                                                          TRUE,
                                                          EXO_PARAM_READWRITE));
 
+  /**
+   * TerminalPreferences:scrolling-single-line:
+   *
+   * Whether to enable scrolling single lines using Shift-Up/-Down.
+   **/
+  g_object_class_install_property (gobject_class,
+                                   PROP_SCROLLING_SINGLE_LINE,
+                                   g_param_spec_boolean ("scrolling-single-line",
+                                                         "scrolling-single-line",
+                                                         "scrolling-single-line",
+                                                         TRUE,
+                                                         EXO_PARAM_READWRITE));
+
   /**
    * TerminalPreferences:shortcuts-no-menukey:
    *
@@ -1350,7 +1341,7 @@ terminal_preferences_get_property (GObject    *object,
   TerminalPreferences *preferences = TERMINAL_PREFERENCES (object);
   GValue              *src;
 
-  g_return_if_fail (prop_id < N_PROPERTIES);
+  _terminal_return_if_fail (prop_id < N_PROPERTIES);
 
   src = preferences->values + prop_id;
   if (G_VALUE_HOLDS (src, pspec->value_type))
@@ -1370,7 +1361,7 @@ terminal_preferences_set_property (GObject      *object,
   TerminalPreferences *preferences = TERMINAL_PREFERENCES (object);
   GValue              *dst;
 
-  g_return_if_fail (prop_id < N_PROPERTIES);
+  _terminal_return_if_fail (prop_id < N_PROPERTIES);
 
   dst = preferences->values + prop_id;
   if (!G_IS_VALUE (dst))
